# OpenTelemetry + Burr

This goes over how to use Burr with OpenTelemetry.

We have two modes:

1. Log OpenTelemetry traces to the Burr UI
2. Log Burr to OpenTelemetry

See [notebook.ipynb](./notebook.ipynb) for a simple overview.
See [application.py](./application.py) for the full code 

See the [documentation](https://burr.dagworks.io/concepts/additional-visibility/#open-telemetry) for more info
